@@ -38,77 +38,6 @@ is_installed <- function(pkg, version = 0) {
   !is.na(installed_version) && installed_version >= version
 }
 
-bioconductor_repositories <- function() {
-  check_bioconductor()
-  if (getRversion() < 3.5) {
-    BiocInstaller::biocinstallRepos()
-  } else {
-    BiocManager::repositories()
-  }
-}
-
-check_bioconductor <- function() {
-  if (getRversion() < 3.5) {
-    check_bioconductor_3()
-  } else {
-    check_bioconductor_3.5()
-  }
-}
-
-check_bioconductor_3 <- function() {
-  if (is_installed("BiocInstaller")) {
-    return()
-  }
-
-  msg <- paste0("'BiocInstaller' must be installed to install Bioconductor packages")
-  if (!interactive()) {
-    stop(msg, call. = FALSE)
-  }
-
-  message(
-    msg, ".\n",
-    "Would you like to install it? ",
-    "This will source <https://bioconductor.org/biocLite.R>."
-  )
-
-  if (menu(c("Yes", "No")) != 1) {
-    stop("'BiocInstaller' not installed", call. = FALSE)
-  }
-
-  # No https in earlier R versions
-  if (getRversion() < 3.2) {
-    suppressMessages(
-      source("http://bioconductor.org/biocLite.R")
-    )
-  } else {
-    suppressMessages(
-      source("https://bioconductor.org/biocLite.R")
-    )
-  }
-}
-
-check_bioconductor_3.5 <- function() {
-  if (is_installed("BiocManager")) {
-    return()
-  }
-
-  msg <- paste0("'BiocManager' must be installed to install Bioconductor packages")
-  if (!interactive()) {
-    stop(msg, call. = FALSE)
-  }
-
-  message(
-    msg, ".\n",
-    "Would you like to install it? "
-  )
-
-  if (menu(c("Yes", "No")) != 1) {
-    stop("'BiocManager' not installed", call. = FALSE)
-  }
-
-  install_cran("BiocManager")
-}
-
 read_dcf <- function(path) {
   fields <- colnames(read.dcf(path))
   as.list(read.dcf(path, keep.white = fields)[1, ])
@@ -170,14 +99,6 @@ file_ext <- function(x) {
   ifelse(pos > -1L, substring(x, pos + 1L), "")
 }
 
-is_bioconductor <- function(x) {
-  if (getRversion() < 3.5) {
-    (x$package != "BiocInstaller") && !is.null(x$biocviews)
-  } else {
-    (x$package != "BiocManager" || x$package != "BiocInstaller") && !is.null(x$biocviews)
-  }
-}
-
 trim_ws <- function(x) {
   gsub("^[[:space:]]+|[[:space:]]+$", "", x)
 }
